qcacmn: Merge Scan manager and scan database umac id

Scan module is single component containing scan manager
services and scan database services so merge Scan manager
and scan database umac component id's.

Change-Id: I02f946824e34bb68c979b6ef3d2026aeb4cd1447
CRs-Fixed: 1113735
diff --git a/umac/cmn_services/inc/wlan_cmn.h b/umac/cmn_services/inc/wlan_cmn.h
index dbce003..bb77a9a 100644
--- a/umac/cmn_services/inc/wlan_cmn.h
+++ b/umac/cmn_services/inc/wlan_cmn.h
@@ -74,9 +74,8 @@
 
 /**
  * enum wlan_umac_comp_id - UMAC component id
  * @WLAN_UMAC_COMP_MLME:        MLME
  * @WLAN_UMAC_COMP_SCANMGR:     SCAN MGR
  * @WLAN_UMAC_COMP_SCANCACHE:   SCAN CACHE
  * @WLAN_UMAC_COMP_MGMT_TXRX:   MGMT Tx/Rx
  *
  * This id is static.
@@ -84,9 +83,8 @@
  */
 enum wlan_umac_comp_id {
 	WLAN_UMAC_COMP_MLME       = 0,
-	WLAN_UMAC_COMP_SCANMGR    = 1,
-	WLAN_UMAC_COMP_SCANCACHE  = 2,
-	WLAN_UMAC_COMP_MGMT_TXRX  = 3,
+	WLAN_UMAC_COMP_SCAN       = 1,
+	WLAN_UMAC_COMP_MGMT_TXRX  = 2,
 };
 
 /**
@@ -74,9 +74,8 @@
 /**
  * enum wlan_umac_comp_id - UMAC component id
- * @WLAN_UMAC_COMP_MLME:        MLME
- * @WLAN_UMAC_COMP_SCANMGR:     SCAN MGR
- * @WLAN_UMAC_COMP_SCANCACHE:   SCAN CACHE
+ * @WLAN_UMAC_COMP_MLME:     MLME
+ * @WLAN_UMAC_COMP_SCAN:     SCAN MGR
  * @WLAN_UMAC_COMP_MGMT_TXRX:   MGMT Tx/Rx
  *